# API Reference

The TMDBFusion API is organized into namespaced services mirroring the TMDB API structure.

## Core

* [**Client**](../_client.md): The main entry point (`TMDBClient`, `AsyncTMDBClient`).
* [**Transport**](../_http.md): internal HTTP transport layer.

## Services (V3)

* [**Account**](account.md): Account specific methods.
* [**Authentication**](authentication.md): Session management.
* [**Certifications**](certifications.md): Movie and TV certifications.
* [**Changes**](changes.md): Change tracking.
* [**Collections**](collections.md): Movie collections.
* [**Companies**](companies.md): Company data.
* [**Configuration**](configuration.md): API configuration.
* [**Credits**](credits.md): Credits data.
* [**Discover**](discover.md): Discover engine.
* [**Find**](find.md): Find by external ID.
* [**Genres**](genres.md): Genre lists.
* [**Guest Sessions**](guest_session.md): Guest auth.
* [**Keywords**](keywords.md): Keyword search.
* [**Lists**](lists.md): User lists.
* [**Movies**](movies.md): Movie data.
* [**Networks**](networks.md): TV networks.
* [**People**](people.md): People data.
* [**Reviews**](reviews.md): Review data.
* [**Search**](search.md): Text search.
* [**Trending**](trending.md): Trending content.
* [**TV**](tv.md): TV Show data.
* [**TV Seasons**](tv_seasons.md): Season data.
* [**TV Episodes**](tv_episodes.md): Episode data.
* [**TV Episode Groups**](tv_episode_groups.md): Episode groups.
* [**Watch Providers**](watch_providers.md): Streaming availability.

## Services (V4)

* [**Account (v4)**](account_v4.md)
* [**Auth (v4)**](auth_v4.md)
* [**Lists (v4)**](lists_v4.md)
